@@ -196,7 +196,7 @@ def process_sample(annotation_bucket, annotation_filename, annotation_path,
     s3 = session.resource("s3")
 
     import environment
-    environment.setup_environment(code_bucket)
+    environment.setup_environment(code_bucket, download_settings=False)
 
     logging.info(f'Processing member {member_id}')
 
