@@ -729,25 +729,65 @@ class OculScholarsPortalPreservation(models.Model):
         if not preserved_item or len(preserved_item) == 0:
             return None, False
 
-        pi = preserved_item.filter(preserved_volumes=volume)
+        # direct hit
+        pis = preserved_item.filter(preserved_volumes=volume)
 
-        if len(pi) > 0:
-            return pi[0], pi[0].preserved
+        volume = str(volume)
+
+        if len(pis) > 0:
+            return pis[0], pis[0].preserved
         else:
+            # do a broader search that allows for the following volume formats:
+            # v24(1)
+            # 1, 2, 3-4, 3.4
+            # 1 to 4
+            basic_volume_regex = r'v(\d+)'
+            unpack_volume_regex = r'(\d+\-\d+)'
+            unpack_volume_words_regex = r'(\d+ to \d+)'
+
+            pis = preserved_item.filter(
+                preserved_volumes__iregex=basic_volume_regex)
+
+            if len(pis) > 0:
+                for pi in pis:
+                    matches = re.findall(basic_volume_regex,
+                                         pi.preserved_volumes)
+
+                    if volume in matches:
+                        return pi, pi.preserved
+
+            pis = preserved_item.filter(
+                preserved_volumes__iregex=unpack_volume_regex)
+
+            if len(pis) > 0:
+                for pi in pis:
+                    matches = re.findall(unpack_volume_regex,
+                                         pi.preserved_volumes)
+
+                    unpacked_range = utils.unpack_range(matches)
+                    print(f'Range unpacked to: {unpacked_range}')
+
+                    if volume in unpacked_range:
+                        return pi, pi.preserved
+
+
+            pis = preserved_item.filter(preserved_volumes=volume)
             return None, False
 
         # OCUL gives volume formats as follows:
         # v24(1)
+        # 1, 2, 3-4, 3.4
+        # 1 to 4
         volume_regex = r'v(\d+)'
 
-        for pi in preserved_item:
-            print(pi.preserved_volumes)
-            matches = re.findall(volume_regex, pi.preserved_volumes)
+        for pis in preserved_item:
+            print(pis.preserved_volumes)
+            matches = re.findall(volume_regex, pis.preserved_volumes)
 
             volume = str(volume)
 
             if volume in matches:
-                return pi, pi.preserved
+                return pis, pis.preserved
 
         return None, False
 
