@@ -44,12 +44,15 @@ def show_preservation(container_title: str, issn: str, volume: str,
     return preservations, doi
 
 
-def unpack_range(s):
+def unpack_range(s: str) -> list:
     """ Converts a range of numbers to a full set"""
     r = []
     for i in s.split(','):
-        if '-' not in i:
+        if '-' not in i and ' to ' not in i:
             r.append(int(i))
+        elif ' to ' not in i:
+            l, h = map(int, i.split(' to '))
+            r += range(l, h + 1)
         else:
             l, h = map(int, i.split('-'))
             r += range(l, h + 1)
@@ -87,6 +90,12 @@ def show_preservation_for_doi(doi_input: str,
     logging.info(f'Checking {doi["DOI"]}: {container_title} '
                  f'({issn}) v{volume} n{no}')
 
+    # the "archive" field is apparently returned if deposited
+    if 'archive' in doi:
+        logging.info(f'{doi_input} asserts preservation in {doi["archive"]}.')
+    else:
+        logging.info(f'{doi_input} asserts no preservation information.')
+
     return show_preservation(container_title, issn, volume, no, doi, archive)
 
 
@@ -247,7 +256,6 @@ def get_preserved_item_record(model, container_title, issn) -> QuerySet | None:
             preserved_item = None
 
             for sub_issn in issn:
-                print(f'Checking sub-issn {sub_issn}')
                 preserved_item = model.objects.filter(issn=sub_issn)
                 if len(preserved_item) > 0:
                     break
@@ -263,7 +271,6 @@ def get_preserved_item_record(model, container_title, issn) -> QuerySet | None:
                 preserved_item = None
 
                 for sub_issn in issn:
-                    print(f'Checking sub-issn {sub_issn}')
                     preserved_item = model.objects.filter(eissn=sub_issn)
                     if len(preserved_item) > 0:
                         break
